@@ -22,73 +22,24 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 from __future__ import annotations
-from bale import User
+from bale import User, ChatType
 from typing import TYPE_CHECKING, Optional, List
 if TYPE_CHECKING:
-    from bale import Bot, Message, User, Photo, Document, Components, RemoveMenuKeyboard, Price, Location, ContactMessage, Video, Audio
+    from bale import Bot, Message, User, Components, RemoveMenuKeyboard, Price, Location, ContactMessage, InputFile
 
 
 __all__ = (
     "Chat",
-    "ChatType"
 )
 
-class ChatType:
-    """This object indicates a Chat Type.
-
-    .. container:: operations
-        .. describe:: x == y
-            Checks if two chat type are equal.
-        .. describe:: x != y
-            Checks if two chat type are not equal.
-    """
-    PRIVATE = "private"
-    GROUP = "group"
-    CHANNEL = "channel"
-
-    __slots__ = (
-        "_type",
-    )
-
-    def __init__(self, _type: str):
-        self._type = _type
-
-    @property
-    def type(self) -> str:
-        return self._type
-
-    def is_private_chat(self):
-        """bool:
-            Return ``True`` if Chat Type is Private"""
-        return self._type == self.PRIVATE
-
-    def is_group_chat(self):
-        """bool:
-            Return ``True`` if Chat Type is Group"""
-        return self._type == self.GROUP
-
-    def is_channel_chat(self):
-        """bool:
-            Return ``True`` if Chat Type is Channel"""
-        return self._type == self.CHANNEL
-
-    def __repr__(self):
-        return f"<ChatType type={self.type}>"
-
-    def __eq__(self, other):
-        return self._type == other
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
 class Chat:
     """This object indicates a chat.
 
     Attributes
     ----------
-        chat_id: str
+        chat_id: :class:`str`
             Unique identifier for this chat.
-        type: :class:`bale.ChatType`
+        type: :class:`str`
             Type of chat.
         title: Optional[:class:`str`]
             Title, for channels and group chats.
@@ -104,12 +55,6 @@ class Chat:
             Primary invite link, for groups and channel. Returned only in bale.Bot.get_chat().
         all_members_are_administrators: bool
             Does everyone have admin access?. Defaults to True. (for Group)
-
-    .. container:: operations
-        .. describe:: x == y
-            Checks if two chat are equal.
-        .. describe:: x != y
-            Checks if two chat are not equal.
     """
     __slots__ = (
         "chat_id",
@@ -124,7 +69,7 @@ class Chat:
         "bot"
     )
 
-    def __init__(self, chat_id: int | str, type: "ChatType", title: Optional[str] = None, username: Optional[str] = None, first_name: Optional[str] = None, last_name: Optional[str] = None,
+    def __init__(self, chat_id: int | str, type: str, title: Optional[str] = None, username: Optional[str] = None, first_name: Optional[str] = None, last_name: Optional[str] = None,
                  pinned_message: Optional["Message"] = None, all_members_are_administrators: Optional[bool] = None, invite_link: Optional[str] = None, bot: 'Bot' = None):
         self.chat_id = chat_id
         self.type = type
@@ -138,9 +83,9 @@ class Chat:
         self.bot = bot
 
     @property
-    def mention(self) -> str | None:
-        """Optional[:class:`str`]"""
-        return ("@" + self.username) if self.username else None
+    def parsed_type(self):
+        """:class:`bale.ChatType`: Represents the parsed type of chat."""
+        return ChatType(self.type)
 
     async def send(self, text: str, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
@@ -148,29 +93,29 @@ class Chat:
         """
         return await self.bot.send_message(self.chat_id, text, components=components)
 
-    async def send_document(self, document: bytes | str | "Document", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_document(self, document: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_document`.
         """
-        return await self.bot.send_document(self.chat_id, document, file_name=file_name, caption=caption)
+        return await self.bot.send_document(self.chat_id, document, caption=caption, components=components)
 
-    async def send_photo(self, photo: bytes | str | "Photo", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_photo(self, photo: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_photo`.
         """
-        return await self.bot.send_photo(self.chat_id, photo, file_name=file_name, caption=caption)
+        return await self.bot.send_photo(self.chat_id, photo, caption=caption, components=components)
 
-    async def send_video(self, video: bytes | str | "Video", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_video(self, video: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_video`.
         """
-        return await self.bot.send_video(self.chat_id, video, file_name=file_name, caption=caption)
+        return await self.bot.send_video(self.chat_id, video, caption=caption, components=components)
 
-    async def send_audio(self, audio: bytes | str | "Audio", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_audio(self, audio: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_audio`.
         """
-        return await self.bot.send_audio(self.chat_id, audio, file_name=file_name, caption=caption)
+        return await self.bot.send_audio(self.chat_id, audio, caption=caption, components=components)
 
     async def send_location(self, location: "Location"):
         """
@@ -185,13 +130,14 @@ class Chat:
         return await self.bot.send_contact(self.chat_id, contact)
 
     async def send_invoice(self, title: str, description: str, provider_token: str, prices: List["Price"], *,
-                   photo_url: Optional[str] = None, need_name: Optional[bool] = False, need_phone_number: Optional[bool] = False,
-                       need_email: Optional[bool] = False, need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
+                   payload: Optional[str] = None, photo_url: Optional[str] = None, need_name: Optional[bool] = False,
+                   need_phone_number: Optional[bool] = False, need_email: Optional[bool] = False,
+                   need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_invoice`
         """
         return await self.bot.send_invoice(self.chat_id, title, description, provider_token, prices,
-                                        photo_url=photo_url, need_name=need_name, need_email=need_email,
+                                        payload=payload, photo_url=photo_url, need_name=need_name, need_email=need_email,
                                         need_phone_number=need_phone_number, need_shipping_address=need_shipping_address, is_flexible=is_flexible)
 
     async def leave(self):
@@ -244,7 +190,7 @@ class Chat:
 
     @classmethod
     def from_dict(cls, data: dict, bot):
-        return cls(bot=bot, chat_id=data.get("id"), type=ChatType(data.get("type")), title=data.get("title"),
+        return cls(bot=bot, chat_id=data.get("id"), type=data.get("type"), title=data.get("title"),
                    username=data.get("username"), first_name=data.get("first_name"), last_name=data.get("last_name"),
                    pinned_message=Message.from_dict(bot=bot, data=data.get("pinned_message")) if data.get("pinned_message") else None,
                    all_members_are_administrators=data.get("all_members_are_administrators", True),
