@@ -6,6 +6,8 @@ from . import InlineKeyboard, MenuKeyboard
 class Components:
     """This object shows a Component.
 
+    .. admonition:: Examples
+        :any:`Components Bot <examples.inline_markup>`
     """
     __slots__ = (
         "_menu_keyboards",
@@ -108,13 +110,14 @@ class Components:
         if not (is_used_menu_keyboard or is_used_inline_keyboard):
             raise TypeError("you must be use menu keyboards or inline keyboards param.")
 
-        correct_children = self._menu_keyboards if bool(self._menu_keyboards) else self._inline_keyboards
-        correct_children_name = "keyboard" if bool(self._menu_keyboards) else "inline_keyboard"
+        correct_children = self._menu_keyboards if is_used_menu_keyboard else self._inline_keyboards
+        correct_children_name = "keyboard" if is_used_menu_keyboard else "inline_keyboard"
         def key(i: Tuple["InlineKeyboard" | "MenuKeyboard", int]):
             return i[1] or 1
 
         sorted_components = sorted(correct_children, key=key)
-        payload = {correct_children_name: []}
+        components = []
+        payload = {correct_children_name: components}
 
         for _, group in groupby(sorted_components, key=key):
             _components = []
@@ -122,6 +125,6 @@ class Components:
                 component = item[0]
                 _components.append(component.to_dict())
 
-            payload[correct_children_name].append(_components)
+            components.append(_components)
 
         return payload
\ No newline at end of file
